@@ -16,7 +16,9 @@ Usage::
     session_client: IoTDataPlaneClient = session.client("iot-data")
     ```
 """
-from mypy_boto3_iot_data.client import IoTDataPlaneClient as Client, IoTDataPlaneClient
+from mypy_boto3_iot_data.client import IoTDataPlaneClient
+
+Client = IoTDataPlaneClient
 
 
 __all__ = ("Client", "IoTDataPlaneClient")
